@@ -1,7 +1,6 @@
 import csv
 from datetime import datetime
 import dateutil.tz
-import feedparser
 from .manual_activity import ManualActivity
 import os
 from .post import Post
@@ -36,6 +35,7 @@ class Home():
             'Country Team',
             'Date Begin',
             'Date End',
+			'Posted Date',
         ]
 
         print('\nPreparing CSV...')
@@ -44,6 +44,12 @@ class Home():
         self.csv_directory = os.path.join(os.path.expanduser('~'), 'SIGACTS')
         self.csv_path = os.path.join(self.csv_directory, self.csv_title)
 
+        print('\nPreparing locations...')
+        locations = urllib.request.urlopen(
+            'http://davidystephenson.com/locations.yaml'
+        )
+        self.locations = yaml.load(locations)
+
         if not os.path.exists(self.csv_directory):
             os.makedirs(self.csv_directory)
 
@@ -64,46 +70,48 @@ class Home():
         self.posts = []
         self.activities = []
 
+        print('\nPreparing feed...')
         sohr = urllib.request.urlopen(
-            'http://173.230.141.9/sohr.yaml'
+            'http://davidystephenson.com/sohr.yaml'
         )
-
         self.sohr = yaml.load(sohr)
 
-        self.entered_date = input(
-            '\nPlease enter a starting time. '
-            '(YYYY-MM-DD-hhmm, or enter "m" to manually enter an activity) '
-        )
+        while True:
+            self.entered_date = input(
+                '\nPlease enter a starting time. '
+                '(YYYY-MM-DD-hhmm, or enter "m" to manually enter an activity) '
+            )
 
-        if self.entered_date == 'm':
-            self.activities.append(ManualActivity(self))
-        else:
-            while True:
-                self.entered_date += (
-                    datetime.now(dateutil.tz.tzlocal()).strftime('%z')
+            if self.entered_date == 'm':
+                self.activities.append(ManualActivity(self))
+                continue
+            
+            self.entered_date += (
+                datetime.now(dateutil.tz.tzlocal()).strftime('%z')
+            )
+
+            try:
+                self.start_date = datetime.strptime(
+                    self.entered_date, '%Y-%m-%d-%H%M%z'
                 )
+                break
+            except ValueError:
+                print('Invalid date. ')
+                self.entered_date = input_date()
+                continue
 
-                try:
-                    self.start_date = datetime.strptime(
-                        self.entered_date, '%Y-%m-%d-%H%M%z'
-                    )
-                    break
-                except ValueError:
-                    self.entered_date = input(
-                        '\nInvalid answer. '
-                        '(Please enter a date in YYYY-MM-DD-hhmm format) '
-                    )
+        self.stop = False
+        for item in self.sohr:
+            if self.stop:
+                break
 
-            self.stop = False
-            for item in self.sohr:
-                if self.stop:
-                    break
+            item_date = (
+                item['date'].strftime('%Y-%m-%dT%H:%M:%S') + '+0000'
+            )
+            item_date = datetime.strptime(item_date, '%Y-%m-%dT%H:%M:%S%z')
 
-                item_date = item['date'].strftime('%Y-%m-%dT%H:%M:%S') + '+0000'
-                item_date = datetime.strptime(item_date, '%Y-%m-%dT%H:%M:%S%z')
-
-                if item_date >= self.start_date:
-                    self.posts.append(Post(self, item, item_date))
+            if item_date >= self.start_date:
+                self.posts.append(Post(self, item, item_date))
 
         print(
             '\nSaved CSV as', self.csv_path,
