@@ -1,5 +1,4 @@
 from .activity import Activity
-from bs4 import BeautifulSoup
 from datetime import datetime
 import dateutil.tz
 from .manual_activity import ManualActivity
@@ -26,12 +25,17 @@ class Post():
         self.province = ''
         if len(self.words) > 1:
             if 'province' in self.words:
-                term_location = self.words.index('province')
-                self.province = self.words[term_location - 1]
-                if self.words[1] == 'province':
-                    term_location = self.clean_content.find('province')
+                index = self.words.index('province')
+                self.province = self.words[index - 1]
+                if index > 1:
+                    if self.words[index - 2][0].isupper():
+                        self.province = (
+                            self.words[index - 2] + ' ' + self.province
+                        )
+                if index <= 2:
+                    index = self.clean_content.find('province')
                     self.clean_content = (
-                        self.clean_content[term_location + 9:]
+                        self.clean_content[index + 9:]
                     )
 
         if self.words[0].lower() in ['rif', 'reef']:
@@ -46,7 +50,18 @@ class Post():
                 self.clean_content = self.clean_content[9:]
             self.town = 'Damascus'
 
-        self.clean_content.replace('.<br/>', '. ')
+        while(
+            self.clean_content.find('<a') != -1 and
+            self.clean_content.find('</a>') != -1
+        ):
+            link_begins = self.clean_content.find('<a')
+            link_ends = self.clean_content.find('</a>') + 4
+            self.clean_content = self.clean_content.replace(
+                self.clean_content[link_begins:link_ends], ''
+            )
+
+        self.clean_content = self.clean_content.replace('<br/>', '')
+
         self.sentences = self.clean_content.split('. ')
         self.contents = []
 
@@ -81,13 +96,13 @@ class Post():
                 else:
                     self.contents.append(sentence)
 
-        answer = self.layout()   
+        answer = self.layout()
 
         while True:
             if answer == '':
                 for number in range(0, len(self.contents)):
                     home.activities.append(Activity(
-                        self.home, self, self.contents[number], number
+                        self.home, self, self.contents[number]
                     ))
                 break
             if answer == 'q':
@@ -126,23 +141,16 @@ class Post():
 
     def contains(self, subject, *args):
         for arg in args:
-            if (
-                isinstance(arg, str)
-            ):
-                if subject.find(arg) != -1:
-                    return True
-            else:
-                for element in arg:
-                    if subject.find(element) != -1:
-                        return True
+            if subject.find(arg) != -1:
+                return True
         return False
-    
+
     def layout(self):
-        print('\nPost content (' + self.time + '):\n' + self.content)
+        print('\nPost content (' + self.time + '):\n' + self.clean_content)
 
         print(
-            '\nAre there ' + str(len(self.contents)) +
-            ' activities in this post '
+            '\nAre there', str(len(self.contents)),
+            'activities in this post',
             'with the following contents:'
         )
 
