@@ -15,39 +15,41 @@ class Property():
             self.value = ''
 
         if self.name == 'Location':
-            self.province = 'Rif ' + self.post.province
+            self.province = self.locate('province')
+            if self.post.province != '':
+                self.province = 'Rif ' + self.post.province
             self.y += self.province + ' comes before "province." '
 
             self.town = ''
-            self.y = 'No town found. '
-
             if self.post.province in ['Aleppo', 'Hama', 'Homs']:
                 self.town = self.post.province
+                self.y += 'Town determined by province. '
             if self.post.province == 'Raqqah':
                 self.town = 'al-Raqqah'
-            self.y = 'Town determined by province. '
+                self.y += 'Town determined by province. '
+            if self.post.province == 'Dimashq':
+                self.town = 'Damascus'
+                self.y += 'Town determined by province. '
 
-            self.town = self.parse_location('town', 'city', 'village')
-
-            if self.post.town != '':
-                self.town = self.post.town
-                self.y = '"' + self.town + '" begins post."'
+            self.town = self.locate('town', 'city', 'village')
 
             for term in ['deir', 'tel']:
                 if term in self.activity.clean_words:
-                    term_location = self.activity.clean_words.index(term)
-                    if len(self.activity.clean_words) > term_location + 1:
+                    index = self.activity.clean_words.index(term)
+                    if len(self.activity.clean_words) > index + 1:
                         self.town = (
-                            self.activity.words[term_location] +
-                            ' ' + self.activity.words[term_location + 1]
+                            self.activity.words[index] +
+                            ' ' + self.activity.words[index + 1]
+                        )
+                        self.y += (
+                            '"' + self.town + '" follows "' + term + '." '
                         )
-                        self.y = '"' + self.town + '" follows "' + term + '." '
             if self.town == 'the':
                 self.value = (
                     self.post.activities[self.number - 1].properties[1].town
                 )
 
-            self.neighborhood = self.parse_location(
+            self.neighborhood = self.locate(
                 'neighborhood',
                 'neighbourhood',
             )
@@ -57,7 +59,7 @@ class Property():
                     properties[1].neighborhood
                 )
 
-            self.area = self.parse_location('area', )
+            self.area = self.locate('area', )
             if self.area == 'the':
                 self.value = (
                     self.post.activities[self.number - 1].properties[1].area
@@ -85,9 +87,19 @@ class Property():
 
         if self.name == 'Lat-Long':
             self.value = ''
+            my_location = self.activity.properties['Location'].value
+
+            for location in self.home.locations:
+                if my_location in location['names']:
+                    self.value = location['Lat-Long']
 
         if self.name == 'Grid Prec':
             self.value = ''
+            my_location = self.activity.properties['Location'].value
+
+            for location in self.home.locations:
+                if my_location in location['names']:
+                    self.value = location['Grid Prec']
 
         if self.name == 'Description':
             self.value = self.activity.content
@@ -106,10 +118,6 @@ class Property():
                 self.value = 'Pro-regime'
 
             self.value = self.check(self.value)
-            if self.value == 'Pro-Regime':
-                self.activity.orientation = 'Regime'
-            else:
-                self.activity.orientation = 'Rebel'
 
         if self.name == 'Ground':
             if self.contains('clashes'):
@@ -121,8 +129,6 @@ class Property():
                     self.y += 'Contains "died," "killed," or "dead." '
 
             self.value = self.check(self.value)
-            if self.value != '':
-                self.activity.verb = 'Clashes'
 
         if self.name == 'Air':
             if self.contains('air'):
@@ -133,10 +139,11 @@ class Property():
                 self.value = 'Ground-to-Air'
 
             self.value = self.check(self.value)
+
             if self.value != '':
-                self.activity.verb = 'Airstrike'
+                self.activity.properties['Orientation'].value = 'Pro-Regime'
             if self.value == 'Ground-to-Air':
-                self.activity.verb = 'Ground-to-Air'
+                self.activity.properties['Orientation'].value = 'Anti-Regime'
 
         if self.name == 'Blast':
             if self.contains('bomb ', 'IED', 'bomber'):
@@ -147,16 +154,12 @@ class Property():
                 self.value = 'SVEST'
 
             self.value = self.check(self.value)
-            if self.value != '':
-                self.activity.verb = self.value
 
         if self.name == 'Targeted':
             if self.post.contains('execut'):
                 self.value = 'Execution'
 
             self.value = self.check(self.value)
-            if self.value != '':
-                self.activity.verb = self.value
 
         if self.name == 'Tactical':
             if self.post.contains('ambush'):
@@ -168,12 +171,12 @@ class Property():
 
             self.value = self.check(self.value)
 
-            if self.value != '':
-                self.activity.verb = self.value
-
         if self.name == 'Outcome':
-            if self.activity.properties[7] in ['IED', 'VBIED']:
+            if self.activity.properties['Blast'].value != '':
                 self.value = 'Effective'
+            else:
+                self.value = ''
+
             self.value = self.check(self.value)
 
         if self.name == 'Full Text':
@@ -197,6 +200,9 @@ class Property():
         if self.name == 'Date End':
             self.value = self.post.short_date
 
+        if self.name == 'Posted Date':
+            self.value = self.post.time
+
     def check(self, value):
         while True:
             answer = input(
@@ -218,52 +224,70 @@ class Property():
             else:
                 return answer
 
-    def parse_location(self, *args):
+    def locate(self, *args):
+        value = ''
         for arg in args:
             if arg in self.activity.clean_words:
-                term_location = self.activity.clean_words.index(arg)
+                index = self.activity.clean_words.index(arg)
 
-                if len(self.activity.clean_words) > term_location + 2:
-                    if self.activity.clean_words[term_location + 1] == 'of':
-                        value = self.activity.words[term_location + 2]
+                if len(self.activity.clean_words) > index + 2:
+                    if self.activity.clean_words[index + 1] == 'of':
+                        if self.activity.words[index + 2] != 'the':
+                            value = self.activity.words[index + 2]
                         self.y += (
                             '"' + value + '" occurs after "' + arg + 'of." '
                         )
 
-                        if self.activity.words[term_location + 3][0].isupper():
-                            value = (
-                                self.activity.words[term_location + 2] + ' ' +
-                                self.activity.words[term_location + 3]
-                            )
-                        
-                        if self.activity.words[term_location - 1][0].isupper():
-                            value = self.activity.words[term_location - 1] + ', ' + value
+                        if len(self.activity.clean_words) > index + 3:
+                            if (
+                                self.activity.words
+                                [index + 3][0].isupper()
 
-                        if self.activity.words[term_location - 2][0].isupper():
-                            value = self.activity.words[term_location - 2] + ' ' + value
+
+                            ):
+                                value = (
+                                    self.activity.words[index + 2] +
+                                    ' ' +
+                                    self.activity.words[index + 3]
+                                )
+
+                        if self.activity.words[index - 1][0].isupper():
+                            if value != '':
+                                value = (
+                                    self.activity.words[index - 1] +
+                                    ', ' + value
+                                )
+                            else:
+                                value = self.activity.words[index - 1]
+
+                        if self.activity.words[index - 2][0].isupper():
+                            value = (
+                                self.activity.words[index - 2] + ' ' + value
+                            )
 
                         if value == 'the':
                             value = ''
                         return value
 
-                value = self.activity.words[term_location - 1]
-                if self.activity.words[term_location - 2][0].isupper():
+                value = self.activity.words[index - 1]
+                if self.activity.words[index - 2][0].isupper():
                     value = (
-                        self.activity.words[term_location - 2] + ' ' +
-                        self.activity.words[term_location - 1]
+                        self.activity.words[index - 2] + ' ' +
+                        self.activity.words[index - 1]
                     )
                 self.y += (
                     '"' + value + '" appears before "' + arg + '." '
                 )
 
                 if value == 'the':
-                            value = ''
+                    value = ''
                 return value
-        return ''
+
+        value = ''
+        return value
 
     def contains(self, *args):
         for arg in args:
-            isinstance(arg, str)
             if self.activity.clean_content.find(arg) != -1:
                 self.y = 'Contains "' + arg + '." '
                 return True
